/**
 * vue-sparklines v2.0.1
 * (c) 2022 tangzhen@me.com
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var vue = require('vue');
var Spot = require('./Spot.js');
var RefLine = require('./RefLine.js');
var props = require('./props.js');
var hooks_useSpotCheck = require('./hooks/useSpotCheck.js');
var hooks_useStyles = require('./hooks/useStyles.js');
var utils_dataToPoints = require('./utils/dataToPoints.js');
var utils_uid = require('./utils/uid.js');
var utils_isEmpty = require('./utils/isEmpty.js');
require('./constant.js');
require('./_chunks/dep-b3aeb592.js');
require('./utils/min.js');
require('./utils/max.js');
require('./utils/mean.js');
require('./utils/midRange.js');
require('./utils/median.js');
require('./utils/stdev.js');
require('./utils/variance.js');
require('./utils/debounce.js');
require('./utils/genColor.js');
require('./Text.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty__default["default"](target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var Line = vue.defineComponent({
  name: "SparklineLine",
  inheritAttrs: false,
  props: props.lineProps,
  setup: function setup(props2) {
    var eventBus = vue.inject("eventBus");
    var id = utils_uid["default"]();

    var _useSpotCheck = hooks_useSpotCheck["default"](),
        checkSpotType = _useSpotCheck.checkSpotType;

    var _useStyles = hooks_useStyles["default"](props2.styles),
        lineStyle = _useStyles.lineStyle,
        fillStyle = _useStyles.fillStyle;

    return {
      eventBus: eventBus,
      id: id,
      checkSpotType: checkSpotType,
      lineStyle: lineStyle,
      fillStyle: fillStyle
    };
  },
  render: function render() {
    var id = this.id,
        data = this.data,
        hasSpot = this.hasSpot,
        spotProps = this.spotProps,
        spotlight = this.spotlight,
        spotStyles = this.spotStyles,
        limit = this.limit,
        width = this.width,
        height = this.height,
        margin = this.margin,
        max = this.max,
        min = this.min,
        styles = this.styles,
        refLineStyles = this.refLineStyles,
        eventBus = this.eventBus,
        checkSpotType = this.checkSpotType,
        lineStyle = this.lineStyle,
        fillStyle = this.fillStyle;

    if (!data.length) {
      return null;
    }

    var props2 = this.$props;
    var hasSpotlight = typeof spotlight === "number";
    var leeway = 10;
    var points = utils_dataToPoints["default"]({
      data: data,
      limit: limit,
      width: width,
      height: height,
      margin: margin,
      max: max,
      min: min,
      textHeight: hasSpotlight ? leeway : 0
    });
    var linePoints = points.map(function (p) {
      return [p.x, p.y];
    }).reduce(function (a, b) {
      return a.concat(b);
    });
    var closePolyPoints = [points[points.length - 1].x, height - margin, margin, height - margin, margin, points[0].y];
    var fillPoints = linePoints.concat(closePolyPoints);
    eventBus.updateValue({
      id: "sparkline__".concat(id),
      color: styles.stroke || styles.fill || "#fff",
      data: data,
      points: points,
      limit: limit,
      type: "line"
    });
    return vue.h("g", function () {
      var items = [];
      items.push(vue.h("polyline", {
        style: fillStyle,
        points: fillPoints.join(" ")
      }), vue.h("polyline", {
        style: lineStyle,
        points: linePoints.join(" ")
      }));
      hasSpotlight && points.map(function (p, key) {
        return checkSpotType({
          props: props2,
          items: items,
          point: p,
          i: key,
          hasSpotlight: hasSpotlight
        }) && items.push(vue.h("circle", {
          style: spotStyles,
          cx: p.x,
          cy: p.y,
          r: spotProps.size,
          rel: data[key],
          key: key
        }));
      });
      hasSpot && items.push(vue.h(Spot["default"], _objectSpread(_objectSpread({}, props2), {}, {
        points: points
      })));
      !utils_isEmpty["default"](refLineStyles) && items.push(vue.h(RefLine["default"], _objectSpread(_objectSpread({}, props2), {}, {
        points: points
      })));
      return items;
    }());
  }
});

exports["default"] = Line;
//# sourceMappingURL=Line.js.map
